package com.bonus.canteen.core.kitchen.service;

import java.util.List;
import java.util.Map;

import com.baomidou.mybatisplus.extension.service.IService;
import com.bonus.canteen.core.kitchen.domain.KitchenDeviceInfo;
import com.bonus.canteen.core.kitchen.dto.KitchenDeviceListDTO;
import com.bonus.canteen.core.kitchen.vo.KitchenDeviceListVO;

/**
 * 厨房设备基础信息Service接口
 *
 * @author xsheng
 * @date 2025-06-16
 */
public interface IKitchenDeviceInfoService extends IService<KitchenDeviceInfo> {
    /**
     * 查询厨房设备基础信息
     *
     * @param deviceId 厨房设备基础信息主键
     * @return 厨房设备基础信息
     */
    public KitchenDeviceListVO selectKitchenDeviceInfoByDeviceId(Long deviceId);

    /**
     * 查询厨房设备基础信息列表
     *
     * @param kitchenDeviceInfo 厨房设备基础信息
     * @return 厨房设备基础信息集合
     */
    public List<KitchenDeviceListVO> selectKitchenDeviceInfoList(KitchenDeviceListDTO kitchenDeviceInfo);

    /**
     * 新增厨房设备基础信息
     *
     * @param kitchenDeviceInfo 厨房设备基础信息
     * @return 结果
     */
    public int insertKitchenDeviceInfo(KitchenDeviceInfo kitchenDeviceInfo);

    /**
     * 修改厨房设备基础信息
     *
     * @param kitchenDeviceInfo 厨房设备基础信息
     * @return 结果
     */
    public int updateKitchenDeviceInfo(KitchenDeviceInfo kitchenDeviceInfo);

    /**
     * 批量删除厨房设备基础信息
     *
     * @param deviceIds 需要删除的厨房设备基础信息主键集合
     * @return 结果
     */
    public int deleteKitchenDeviceInfoByDeviceIds(List<Long> deviceIds);

    /**
     * 删除厨房设备基础信息信息
     *
     * @param deviceId 厨房设备基础信息主键
     * @return 结果
     */
    public int deleteKitchenDeviceInfoByDeviceId(Long deviceId);

    List<KitchenDeviceInfo> selectKitchenDeviceInfoSelect(KitchenDeviceListDTO kitchenDeviceInfo);

    Map<Integer, String> deviceType();
}
