package com.bonus.canteen.core.kitchen.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.NotNull;

import com.bonus.canteen.core.kitchen.dto.KitchenDeviceListDTO;
import com.bonus.canteen.core.kitchen.vo.KitchenDeviceListVO;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.kitchen.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.kitchen.domain.KitchenDeviceInfo;
import com.bonus.canteen.core.kitchen.service.IKitchenDeviceInfoService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 厨房设备基础信息Controller
 *
 * @author xsheng
 * @date 2025-06-16
 */
@Api(tags = "厨房设备基础信息接口")
@RestController
@RequestMapping("/kitchen_device_info")
public class KitchenDeviceInfoController extends BaseController {
    @Autowired
    private IKitchenDeviceInfoService kitchenDeviceInfoService;

    /**
     * 查询厨房设备基础信息列表
     */
    @ApiOperation(value = "查询厨房设备基础信息列表")
    @GetMapping("/list")
    public TableDataInfo list(KitchenDeviceListDTO kitchenDeviceInfo) {
        startPage();
        List<KitchenDeviceListVO> list = kitchenDeviceInfoService.selectKitchenDeviceInfoList(kitchenDeviceInfo);
        return getDataTable(list);
    }

    @ApiOperation(value = "查询厨房设备基础信息列表")
    @GetMapping("/select")
    public AjaxResult select(KitchenDeviceListDTO kitchenDeviceInfo) {
        try{
            List<KitchenDeviceInfo> list = kitchenDeviceInfoService.selectKitchenDeviceInfoSelect(kitchenDeviceInfo);
            return success(list);
        }catch (Exception e) {
            return error(e.getMessage());
        }
    }

    @ApiOperation(value = "查询厨房设备基础信息列表")
    //@RequiresPermissions("kitchen:info:list")
    @GetMapping("/deviceType")
    public AjaxResult deviceType() {
        try{
            return success(kitchenDeviceInfoService.deviceType());
        }catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 导出厨房设备基础信息列表
     */
    @ApiOperation(value = "导出厨房设备基础信息列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:info:export")
    @SysLog(title = "厨房设备基础信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出厨房设备基础信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, KitchenDeviceListDTO kitchenDeviceInfo) {
        List<KitchenDeviceListVO> list = kitchenDeviceInfoService.selectKitchenDeviceInfoList(kitchenDeviceInfo);
        ExcelUtil<KitchenDeviceListVO> util = new ExcelUtil<KitchenDeviceListVO>(KitchenDeviceListVO.class);
        util.exportExcel(response, list, "厨房设备基础信息数据");
    }

    /**
     * 获取厨房设备基础信息详细信息
     */
    @ApiOperation(value = "获取厨房设备基础信息详细信息")
    //@RequiresPermissions("kitchen:info:query")
    @GetMapping(value = "/details")
    public AjaxResult getInfo(@NotNull Long deviceId) {
        return success(kitchenDeviceInfoService.selectKitchenDeviceInfoByDeviceId(deviceId));
    }

    /**
     * 新增厨房设备基础信息
     */
    @ApiOperation(value = "新增厨房设备基础信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:info:add")
    @SysLog(title = "厨房设备基础信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增厨房设备基础信息")
    @PostMapping("/add")
    public AjaxResult add(@RequestBody KitchenDeviceInfo kitchenDeviceInfo) {
        try {
            return toAjax(kitchenDeviceInfoService.insertKitchenDeviceInfo(kitchenDeviceInfo));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改厨房设备基础信息
     */
    @ApiOperation(value = "修改厨房设备基础信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:info:edit")
    @SysLog(title = "厨房设备基础信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改厨房设备基础信息")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody KitchenDeviceInfo kitchenDeviceInfo) {
        try {
            return toAjax(kitchenDeviceInfoService.updateKitchenDeviceInfo(kitchenDeviceInfo));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除厨房设备基础信息
     */
    @ApiOperation(value = "删除厨房设备基础信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:info:remove")
    @SysLog(title = "厨房设备基础信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除厨房设备基础信息")
	@PostMapping("/del")
    public AjaxResult remove(@RequestBody  List<Long> deviceIds) {
        return toAjax(kitchenDeviceInfoService.deleteKitchenDeviceInfoByDeviceIds(deviceIds));
    }
}
